[Bf-blender-cvs] [9c93c0b] master: Bullet: making bullet friction workaround more furureproof by using the __apple_build_version__ macro, TODO: check if problem persists with newer clang

Jens Verwiebe noreply at git.blender.org
Sat Apr 19 14:11:05 CEST 2014


Commit: 9c93c0bf08c0bc73d2c09e7f8c57721b557eb222
Author: Jens Verwiebe
Date:   Sat Apr 19 14:10:49 2014 +0200
https://developer.blender.org/rB9c93c0bf08c0bc73d2c09e7f8c57721b557eb222

Bullet: making bullet friction workaround more furureproof by using the __apple_build_version__ macro, TODO: check if problem persists with newer clang

===================================================================

M	extern/bullet2/src/BulletDynamics/ConstraintSolver/btSolverBody.h

===================================================================

diff --git a/extern/bullet2/src/BulletDynamics/ConstraintSolver/btSolverBody.h b/extern/bullet2/src/BulletDynamics/ConstraintSolver/btSolverBody.h
index 1a6b187..8e4456e 100644
--- a/extern/bullet2/src/BulletDynamics/ConstraintSolver/btSolverBody.h
+++ b/extern/bullet2/src/BulletDynamics/ConstraintSolver/btSolverBody.h
@@ -37,9 +37,9 @@ struct	btSimdScalar
 	{
 
 	}
-/* workaround for an clang 3.4 issue, friction would fail with forced inlining */
-#if (defined(__APPLE__) && defined(__clang__) && (__clang_major__ == 5) && (__clang_minor__ == 1)) \
-	|| (defined(__clang__) && (__clang_major__ == 3) && (__clang_minor__ == 4))
+/* workaround for clang 3.4 ( == apple clang 5.1 ) issue, friction would fail with forced inlining */
+#if (defined(__clang__) && defined(__apple_build_version__) &&  (__clang_major__ == 5) && (__clang_minor__ == 1)) \
+|| (defined(__clang__) && !defined(__apple_build_version__) && (__clang_major__ == 3) && (__clang_minor__ == 4))
 	inline __attribute__ ((noinline)) btSimdScalar(float	fl)
 #else
 	SIMD_FORCE_INLINE	btSimdScalar(float	fl)




More information about the Bf-blender-cvs mailing list